read_job_offer: read_job_offer

Description Usage Arguments Value Examples

View source: R/Euraxess.R

Description

Read the job offer passed as url from euraxess and extract : - the general text on it - the content of the tickle box - two parameter of location

The text is extracted in a broad way using "#node-" + id of the job offer, it is the only way to generalize to all the jobs offers.

Usage

1

Arguments

url

: Url of a job offer.

Value

datatable with the content of the job offer.

Examples

1
2
3
4
5
## Not run: 
url <- "https://euraxess.ec.europa.eu/jobs/498418"
df<-read_job_offer(url)

## End(Not run)

Cdk29/EuRaxess documentation built on July 8, 2021, 4:43 a.m.