Description Usage Arguments Examples
Function to scrape all the urls of job from result page. Allow to used some filter from euraxess, like "early stage researcher". Used in scrape_urls_euraxess.
1 | scrape_urls_page(search_url)
|
search_url |
: Url of one results page of a search for job offer. Can be the first or page 17. Passed as input by scrape scrape_urls_euraxess. |
1 2 3 4 5 | ## Not run:
search_url <- "https://euraxess.ec.europa.eu/jobs/search/field_research_profile/first-stage-researcher-r1-446?sort=created&order=desc"
urls <- scrape_urls_pages(search_url)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.