Description Usage Arguments Value Examples
Read the job offer passed as url from euraxess and extract : - the general text on it - the content of the tickle box - two parameter of location
The text is extracted in a broad way using "#node-" + id of the job offer, it is the only way to generalize to all the jobs offers.
1 |
url |
: Url of a job offer. |
datatable with the content of the job offer.
1 2 3 4 5 | ## Not run:
url <- "https://euraxess.ec.europa.eu/jobs/498418"
df<-read_job_offer(url)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.