Description Usage Arguments Value Examples
Summarized a job offer using textrank. During the execution of the function, the terminology is reduced to the keywords passed as input to get a summary containing only sentence with keywords of interrest.
1 | resume_job_offer(df, tagger, key_words)
|
df |
: df of job offer scrapped by read_offer_offer. |
tagger |
: a udpipe model for english annotation. |
key_words |
: key words to create the summary with pagerank |
a summary of the job offer that can be empty of no sentence contain the keywords.
1 2 3 4 5 6 7 8 | ## Not run:
key_words<-c("systematic", "review", "text", "mining", "text")
tagger <- udpipe_load_model("english-gum-ud-2.4-190531.udpipe")
resume_job_offer(df, tagger, key_words)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.