Description Usage Arguments Examples
Function recollect all the url of job offers from euraxes to run read_job_offer.
1 | scrape_urls_euraxess(search_url, last_page)
|
search_url |
: url of the first page of results of a job offers search. |
last_page |
: last page of the search to be scrapped using this function. 3 mean that the first page of resuls will be scrapped, then the three others. |
1 2 3 4 5 6 | ## Not run:
scrape_urls_euraxess(search_url, 3)
urls<-scrape_urls_euraxess(search_url, 3)
job_offer<-pblapply(urls, read_job_offer)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.